# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/).

## [Unreleased]


## [0.1.0] - 2026-03-10

### Added

- 15 chart types: bar, histogram, heatmap, box plot, line, scatter,
  comparison bar, diverging bar, summary box, percentile ladder,
  normalized speedup, stacked bar, sparkline table, CDF, rank table
- Zero-dependency core library (Python 3.10+)
- CLI interface (`textcharts` command)
- MCP server (`textcharts-mcp` command)
- Sphinx documentation with Furo theme

[0.1.0]: https://github.com/joeharris76/textcharts/releases/tag/v0.1.0
